<?php
use Bitrix\Main\Localization\Loc;
use Bitrix\Main\ModuleManager;
use Bitrix\Main\Config\Option;
use Bitrix\Main\EventManager;
use Bitrix\Main\Application;
use Bitrix\Main\IO\Directory;

Loc::loadMessages(__FILE__);

class emt_emailtools extends CModule{

    public function __construct(){

        if(file_exists(__DIR__.'/version.php')){
    
            $arModuleVersion = array();
    
            include(__DIR__.'/version.php');
            \Bitrix\Main\Loader::includeModule('sale');	
            
            $this->MODULE_ID 		   = str_replace('_', '.', get_class($this));
            $this->MODULE_VERSION 	   = $arModuleVersion['VERSION'];
            $this->MODULE_VERSION_DATE = $arModuleVersion['VERSION_DATE'];
            $this->MODULE_NAME 		   = Loc::getMessage('EMT_EMAILTOOLS_NAME');
            $this->MODULE_DESCRIPTION  = Loc::getMessage('EMT_EMAILTOOLS_DESCRIPTION');
            $this->PARTNER_NAME 	   = Loc::getMessage('EMT_EMAILTOOLS_PARTNER_NAME');
            $this->PARTNER_URI  	   = Loc::getMessage('EMT_EMAILTOOLS_PARTNER_URI');
        }
    
        return false;
    }

    public function DoInstall(){

        global $APPLICATION;
    
        if(CheckVersion(ModuleManager::getVersion('main'), '14.00.00')){
    
            $this->InstallFiles();
            $this->InstallDB();
    
            ModuleManager::registerModule($this->MODULE_ID);
    
            $this->InstallEvents();
        }else{
    
            $APPLICATION->ThrowException(
                Loc::getMessage('EMT_EMAILTOOLS_INSTALL_ERROR_VERSION')
            );
        }
    
        $APPLICATION->IncludeAdminFile(
            Loc::getMessage('EMT_EMAILTOOLS_INSTALL_TITLE').' \''.Loc::getMessage('EMT_EMAILTOOLS_NAME').'\'',
            __DIR__.'/step.php'
        );
    
        return false;
    }

    public function InstallFiles(){

        CopyDirFiles(
            __DIR__.'/assets/scripts',
            Application::getDocumentRoot().'/bitrix/js/'.$this->MODULE_ID.'/',
            true,
            true
        );
    
        /*CopyDirFiles(
            __DIR__.'/assets/styles',
            Application::getDocumentRoot().'/bitrix/css/'.$this->MODULE_ID.'/',
            true,
            true
        );*/
    
        return false;
    }

    public function InstallDB(){

        return false;
    }
    
    public function InstallEvents(){

        EventManager::getInstance()->registerEventHandler(
            'main',
            'OnBeforeEndBufferContent',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'appendScriptsToPage'
        );

        EventManager::getInstance()->registerEventHandler(
            'sale',
            'OnBasketAdd',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'onBasketAddHandler'
        );
        
        EventManager::getInstance()->registerEventHandler(
            'sale',
            'OnOrderAdd',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'onOrderAddHandler'
        );

        EventManager::getInstance()->registerEventHandler(
            'sale',
            'OnSaleOrderSaved',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'onSaleOrderSaved'
        );   

        return false;
    }  

    public function DoUninstall(){

        global $APPLICATION;
    
        $this->UnInstallFiles();
        $this->UnInstallDB();
        $this->UnInstallEvents();
    
        ModuleManager::unRegisterModule($this->MODULE_ID);
    
        $APPLICATION->IncludeAdminFile(
            Loc::getMessage('EMT_EMAILTOOLS_UNINSTALL_TITLE').' \''.Loc::getMessage('EMT_EMAILTOOLS_NAME').'\'',
            __DIR__.'/unstep.php'
        );
    
        return false;
    }

    public function UnInstallFiles(){

        Directory::deleteDirectory(
            Application::getDocumentRoot().'/bitrix/js/'.$this->MODULE_ID
        );
    
        return false;
    }

    public function UnInstallDB(){
        Option::delete($this->MODULE_ID);
        return false;
    }

    public function UnInstallEvents(){

        EventManager::getInstance()->unRegisterEventHandler(
            'main',
            'OnBeforeEndBufferContent',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'appendScriptsToPage'
        );
        EventManager::getInstance()->unRegisterEventHandler(
            'sale',
            'OnBasketAdd',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'onBasketAddHandler'
        );

        EventManager::getInstance()->unRegisterEventHandler(
            'sale',
            'OnOrderAdd',
            $this->MODULE_ID,
            'Emt\Emailtools\Main',
            'onOrderAddHandler'
        );

        return false;
    }


}