<?php
namespace Emt\Emailtools;

use Bitrix\Main\Config\Option;
use Bitrix\Main\Page\Asset;
use Bitrix\Main\Page\AssetLocation;
use Bitrix\Main\Web\HttpClient;

class Main{

	private static $api_key;
	private static $payment_systems;
	private static $server_name;
	private static $server_url;
	private static $module_id;
	private static $inited = false;
	private static $tracker_url = 'https://emailtools.ru/tracker/';
	private static $log_filename = 'emt_log.txt';
	private static $debug = true;

	public static function init()
	{
		self::$module_id = pathinfo(dirname(__DIR__))['basename'];
		self::$api_key = Option::get(self::$module_id, 'api_key', '');
		$payment_systems_data = Option::get(self::$module_id, 'payment_systems', '');
		if(!empty($payment_systems_data))
		{
			self::$payment_systems = explode(' ', $payment_systems_data);
		} else {
			self::$payment_systems = [];
		}
		self::$server_name = $_SERVER ['HTTP_HOST'];
		self::$server_url = ($_SERVER['HTTPS'] == 'on') ? 'https://'.self::$server_name : 'http://'.self::$server_name;
		self::$inited = true;
	}

	private static function log($operation, $response)
	{
		$log_filename = $_SERVER["DOCUMENT_ROOT"].'/'.self::$log_filename;
		if (date ("Y-m-d", filemtime($log_filename)) !== date('Y-m-d')) 
		{
			unlink($log_filename);
		}
		$log  = "Date: ".date("F j, Y, g:i a").PHP_EOL.
        "Operation: ".$operation.PHP_EOL.
        "Response: ".$response.PHP_EOL.
        "-------------------------".PHP_EOL;
		file_put_contents($log_filename, $log, FILE_APPEND);
	}

	private static function checkEnv()
	{
		return (!defined("ADMIN_SECTION") && $ADMIN_SECTION !== true && !empty(self::$api_key));
	}

	private static function fetchProductIds($arBasket)
	{
		$result = [];
		foreach($arBasket as $item)
		{
			$result[] = $item['PRODUCT_ID'];
		}
		if(empty($result)) return '';
		else return implode(',', $result);
	}

	private static function operationSend($arData)
	{
		$curl = curl_init();
		curl_setopt_array($curl, [
			CURLOPT_SSL_VERIFYPEER => false,
			CURLOPT_SSL_VERIFYHOST => false,
			CURLOPT_HTTPHEADER =>  [
				'Content-Type: application/x-www-form-urlencoded',
				'Accept: */*',
				'Origin: '.self::$server_url,
			],
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_URL => self::$tracker_url,
			CURLOPT_POST => true,
			CURLOPT_POSTFIELDS => http_build_query($arData),
		]);
		$response = curl_exec($curl);
		curl_close($curl);
		if(self::$debug)
		{
			self::log($arData['task'], print_r(['data' => $arData, 'response' => $response], true));
		}
	}

	public function appendScriptsToPage()
	{
		if(!self::$inited) self::init();
		if(!self::checkEnv()) return false;
		if(Option::get(self::$module_id, 'load_jquery', ''))
		{
			\CJSCore::Init(['jquery2']);
		}
		Asset::getInstance()->addString('<script src="https://emailtools.ru/js/api/v1/tools.js" defer="" async=""></script><script type="text/javascript">window.EMT = window.EMT || {};EMT._client_id = '.self::$api_key.';</script>', true, AssetLocation::BEFORE_CSS);
		Asset::getInstance()->addJs('/bitrix/js/'.self::$module_id.'/emailtools.js');
	}

	public function onBasketAddHandler($ID, $arFields)
	{
		if(!self::$inited) self::init();
		if(!self::checkEnv() || !isset($_COOKIE['emt_uuuid']) || empty($_COOKIE['emt_uuuid'])) return false;
		$data = [
			'task' => 'addtocart',
			'client_id' => self::$api_key,
			'base_domain' => $_SERVER ['HTTP_HOST'],
			'productid' => $arFields['PRODUCT_ID'],
			'uuuid' => $_COOKIE['emt_uuuid'],
		];
		self::operationSend($data);
		/*if(isset($_SESSION['emt_deferred']) && !empty($_SESSION['emt_deferred']))
		{
			$_SESSION['emt_deferred']['products'] = $arFields['PRODUCT_ID'];
			self::operationSend($_SESSION['emt_deferred']);
			unset($_SESSION['emt_deferred']);
		}*/
	}

	public function onOrderAddHandler($ID, $arFields)
	{
		if(!self::$inited) self::init();
		if(!self::checkEnv() || !isset($_COOKIE['emt_uuuid']) || empty($_COOKIE['emt_uuuid'])) return false;
		$products = self::fetchProductIds($arFields['BASKET_ITEMS']);
		$sendOrderData = [
			'task' => 'sendOrder',
			'client_id' => self::$api_key,
			'base_domain' => self::$server_name,
			'uuuid' => $_COOKIE['emt_uuuid'],
			'name' => $arFields['PROFILE_NAME'],
			'email' => $arFields['USER_EMAIL'],
			'orderid' => $arFields['ID'],
			'products' => $products,
			'total' => $arFields['PRICE'],
			'permission' =>  'subscribe' // unsubscribe
		];
		if(!empty($products))
		{
			if(!empty($arFields['PAY_SYSTEM_ID']) && 
			in_array($arFields['PAY_SYSTEM_ID'], self::$payment_systems))
			{
				$onlinepayData = [
					'task' => 'onlinepay',
					'client_id' => self::$api_key,
					'base_domain' => self::$server_name,
					'uuuid' => $_COOKIE['emt_uuuid'],
					'email' => $arFields['USER_EMAIL'],
				];
				self::operationSend($onlinepayData);
			}
			self::operationSend($sendOrderData);
		} /*else {
			// заказ создан программно, сохраняем его в сессию
			$_SESSION['emt_deferred'] = $sendOrderData;
		}*/

	}
	
}